# ***CONTRIBUTING***

When contributing to this repository, please first discuss the 
change you wish to make via issue, email, or any other method 
with the owners of this repository before making a change. 

Please note we have a code of conduct, please follow it in all 
your interactions with the project.


## **Pull Request Process**
--------

1. Ensure any install or build dependencies are removed before 
the end of the layer when doing a build.

2. Update the [readme.md](readme.md) with details of changes to the 
interface, this includes new environment variables, exposed 
ports, useful file locations and container parameters.

3. Increase the version numbers in any examples files and 
the [readme.md](readme.md) to the new version that this Pull Request 
would represent. The versioning scheme we use is [SemVer](http://semver.org/).

4. You may merge the Pull Request in once you have the 
sign-off of by me, or if you do not have permission to do 
that, you may request the second reviewer to merge it for 
you.
   

## **Code of Conduct**
--------

Read the [code of conduct](code_of_conduct.md) before proseding.
